"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Game = void 0;
var market_1 = require("./market");
var pile_1 = require("./pile");
var player_1 = require("./player");
var turn_1 = require("./turn");
var events_1 = require("./events");
var errors_1 = require("./errors");
var logger_1 = require("./logger");
var logger = (0, logger_1.default)("index.js");
var InvalidArgumentTypeError = (0, errors_1.createTypeError)("InvalidArgumentTypeError");
var Game = /** @class */ (function () {
    function Game(props) {
        var _this = this;
        this.noOfDecks = 1;
        this.noOfPlayers = 0;
        this.players = [];
        /**
         * distribute 4 cards to each player one by one
         */
        this.deal = function () {
            for (var i = 1; i <= 4; i++) {
                _this.players.forEach(function (player) {
                    player.pick();
                });
            }
        };
        this.playFirstCard = function (firstCard) {
            var cards = _this.market.pick(1);
            if (firstCard)
                _this.pile.push([firstCard]);
            else
                _this.pile.push(cards);
            return cards[0];
        };
        if (!Number(props.noOfDecks))
            throw InvalidArgumentTypeError("props.noOfDecks", Number);
        if (!Number(props.noOfPlayers))
            throw InvalidArgumentTypeError("props.noOfPlayers", Number);
        this.noOfDecks = Number(props.noOfDecks || 1);
        this.noOfPlayers = props.noOfPlayers;
        this.pile = new pile_1.default({ emitter: events_1.emitter });
        this.market = new market_1.default({
            noOfDecks: props.noOfDecks,
            emitter: events_1.emitter,
            pile: function () { return _this.pile; },
        });
        this.initPlayers();
        this.turn = new turn_1.default({
            players: this.players,
            emitter: events_1.emitter,
        });
        this.emitter = events_1.emitter;
        this.deal();
        this.turn.execute(this.playFirstCard(props.firstCard), true);
    }
    Game.prototype.initPlayers = function () {
        var _this = this;
        this.players = [];
        // create and load players
        for (var i = 1; i <= this.noOfPlayers; i++) {
            var player = new player_1.default({
                id: i,
                emitter: events_1.emitter,
                market: function () { return _this.market; },
                pile: function () { return _this.pile; },
            });
            this.players.push(player);
        }
    };
    return Game;
}());
exports.Game = Game;
exports.default = Game;
//# sourceMappingURL=index.js.map