"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Market = void 0;
var deck_1 = require("./deck");
var errors_1 = require("./errors");
var events_1 = require("events");
var logger_1 = require("./logger");
var logger = (0, logger_1.default)("market.js");
var OutOfRangeError = (0, errors_1.default)("OutOfRangeError");
var PropNotFoundError = (0, errors_1.default)("PropNotFoundError");
/**
 * @event market:create
 * @event market:pick
 */
var Market = /** @class */ (function () {
    function Market(props) {
        var _this = this;
        this.cards = [];
        this.shuffle = function () {
            _this.cards = [];
            for (var i = 1; i <= _this.noOfDecks; i++) {
                var deck = new deck_1.default({ emitter: _this.emitter });
                deck.shuffle().forEach(function (card) {
                    _this.cards.push(card);
                });
            }
            _this.emitter.emit("market:create", _this.cards.slice(0));
        };
        this.pick = function (no) {
            if (no === void 0) { no = 1; }
            if (no >= _this.cards.length) {
                if (!_this.pile)
                    throw PropNotFoundError("pile");
                else {
                    // get more cards from the pile
                    _this.pile()
                        .reset()
                        .forEach(function (card) { return _this.cards.push(card); });
                    _this.cards = _this.cards.sort(function (a, b) { return Math.random() - 0.5; });
                    if (no > _this.cards.length) {
                        throw OutOfRangeError("cards");
                    }
                }
            }
            var pickedCards = _this.cards.splice(0, no);
            _this.emitter.emit("market:pick", pickedCards);
            return pickedCards;
        };
        this.count = function () { return _this.cards.length; };
        this.noOfDecks = props.noOfDecks || 1;
        this.pile = props.pile;
        if (!props.emitter) {
            logger.warn("props.emitter not defined");
            this.emitter = props.emitter = new events_1.EventEmitter();
        }
        else {
            this.emitter = props.emitter;
        }
        this.shuffle();
    }
    return Market;
}());
exports.Market = Market;
exports.default = Market;
//# sourceMappingURL=market.js.map