"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pile = void 0;
var shapes_1 = require("./shapes");
var errors_1 = require("./errors");
var errors_2 = require("./errors");
var events_1 = require("events");
var logger_1 = require("./logger");
var logger = (0, logger_1.default)("pile.js");
var InvalidArgumentTypeError = (0, errors_2.createTypeError)("InvalidArgumentTypeError");
/** blocks attempts to play a card that doesn't match the top card in the pile */
var LastCardMismatchError = (0, errors_1.default)("LastCardMismatchError");
/** blocks attempts to play no cards */
var NoCardSuppliedError = (0, errors_1.default)("NoCardSuppliedError");
/**
 * @event pile:push
 * @event pile:reset
 */
var Pile = /** @class */ (function () {
    function Pile(props) {
        var _this = this;
        this.cards = [];
        this.noOfPlays = 0;
        this.top = function () { return _this.cards[_this.cards.length - 1] || null; };
        this.firstCardIsWhot = function () {
            return _this.top().shape === shapes_1.default.Whot && _this.noOfPlays === 1;
        };
        this.push = function (_cards_) {
            var _a;
            if (Array.isArray(_cards_)) {
                if (_cards_.length > 0) {
                    var lastCard = _cards_[_cards_.length - 1];
                    if (!_this.top() ||
                        _this.top().matches(lastCard) ||
                        _this.firstCardIsWhot()) {
                        _this.top() && _this.top().reset(); //reset card to original config (e.g. set iNeed to null)
                        _cards_.forEach(function (card) {
                            _this.cards.push(card);
                        });
                        _this.emitter.emit("pile:push", _cards_);
                        _this.noOfPlays += _cards_.length;
                    }
                    else {
                        throw LastCardMismatchError("pile: ".concat((_a = _this.top()) === null || _a === void 0 ? void 0 : _a.render(), ", play: ").concat(lastCard === null || lastCard === void 0 ? void 0 : lastCard.render()));
                    }
                }
                else {
                    throw NoCardSuppliedError("");
                }
            }
            else {
                throw InvalidArgumentTypeError("_cards_", Array);
            }
        };
        this.reset = function () {
            _this.emitter.emit("pile:reset", _this.top());
            return _this.cards.splice(0, _this.cards.length - 1);
        };
        if (!props.emitter) {
            logger.warn("props.emitter not defined");
            this.emitter = props.emitter = new events_1.EventEmitter();
        }
        else {
            this.emitter = props.emitter;
        }
    }
    return Pile;
}());
exports.Pile = Pile;
exports.default = Pile;
//# sourceMappingURL=pile.js.map