/// <reference types="node" />
import { CardShape } from "./shapes";
import { EventEmitter } from "./events";
import Card from "./card";
import Pile from "./pile";
import Market from "./market";
import { CardMove } from "./moves";
declare type PlayerProps = {
    id: number;
    emitter: EventEmitter;
    market: () => Market;
    pile: () => Pile;
};
/**
 * A player participates in a whot game, by holding and playing a card when it's his/her turn
 *
 * @event player:play when a card is played by being added to the pile
 * @event player:market when the player goes to market
 */
export declare class Player {
    id: number;
    emitter: EventEmitter;
    market: () => Market;
    pile: () => Pile;
    cards: Card[];
    turn: boolean;
    hasWon: boolean;
    toPick: number;
    emit: (event: string, data: any) => Player;
    constructor(props: PlayerProps);
    /**
     * checks that it is possible to play a card
     *
     * condition is true if:
     *   - card matches card at the top of the pile
     *   - top pile card is a Whot!, and is the first card in the game
     */
    validator: (card: Card) => boolean;
    add: (_cards_: Card[]) => void;
    hand: () => Card[];
    pick: () => Card[];
    play: (index: number, iNeed?: CardShape) => Card;
    lastCard: () => boolean;
    empty: () => boolean;
    canPlay: () => boolean;
    canMatchMove: (move?: CardMove) => boolean;
    render: () => string;
}
export default Player;
