/// <reference types="node" />
import { EventEmitter } from "events";
import Player from "./player";
import Card from "./card";
declare type TurnProps = {
    players: Player[];
    emitter: EventEmitter;
};
/**
 * @event turn:switch
 * @event turn:holdon
 * @event turn:pick-two
 * @event turn:pick-three
 * @event turn:suspension
 */
export declare class Turn {
    players: Player[];
    emitter: EventEmitter;
    constructor(props: TurnProps);
    initPlayers(): void;
    next: () => Player | undefined;
    all: (fn?: ((player: Player) => void) | undefined) => number;
    /**
     * @param {Number} skip ignore this number of players
     */
    switch: (skip?: number) => this;
    /**
     * @param {number} noOfPlayers how many players are to pick
     * @param {number} count how many cards is each player to pick
     *
     * @returns affected players
     */
    setToPick: (noOfPlayers: number, count: number, noSwitch?: boolean) => Player[];
    holdon: (noSwitch?: boolean) => void;
    pickTwo: (noSwitch?: boolean) => this;
    pickThree: (noSwitch?: boolean) => this;
    skipped: (no: number) => Player[];
    /**
     * @param {Boolean} isStar check if the card played is a star
     */
    suspension: (isStar?: boolean, noSwitch?: boolean) => void;
    generalMarket: (noSwitch?: boolean) => Player[];
    count: () => number;
    /**
     * @param {Card} card
     */
    execute: (card: Card, noSwitch?: boolean) => void;
}
export default Turn;
